@@ -3,15 +3,16 @@
 #' @inheritParams factory_gt
 #' @return flextable object
 #' @noRd
-factory_flextable <- function(tab,
-                              align = NULL,
-                              hrule = NULL,
-                              notes = NULL,
-                              title = NULL,
-                              output_format = "flextable",
-                              output_file = NULL,
-                              ...) {
-
+factory_flextable <- function(
+  tab,
+  align = NULL,
+  hrule = NULL,
+  notes = NULL,
+  title = NULL,
+  output_format = "flextable",
+  output_file = NULL,
+  ...
+) {
   insight::check_if_installed("flextable")
 
   span <- get_span_kableExtra(tab)
@@ -32,26 +33,30 @@ factory_flextable <- function(tab,
   # user-supplied notes at the bottom of table
   if (!is.null(notes)) {
     for (i in rev(seq_along(notes))) {
-      out <- flextable::add_footer_row(out,
+      out <- flextable::add_footer_row(
+        out,
         values = notes[[i]],
-        colwidths = table_width)
+        colwidths = table_width
+      )
     }
   }
 
   # theme
-  theme_ms <- getOption("modelsummary_theme_flextable",
-                        default = theme_ms_flextable)
+  theme_ms <- getOption(
+    "modelsummary_theme_flextable",
+    default = theme_ms_flextable
+  )
   out <- theme_ms(out, hrule = hrule)
 
   # spanning headers
   for (i in seq_along(span)) {
-    out <- flextable::add_header_row(out,
+    out <- flextable::add_header_row(
+      out,
       colwidths = span[[i]],
       values = names(span[[i]])
     )
   }
 
-
   # output
   if (is.null(output_file)) {
     return(out)
