@@ -5,5 +5,6 @@ using("tinysnapshot")
 # markdown d-column snapshot
 mod <- lm(mpg ~ I(hp / 1000) + am + vs + factor(cyl), mtcars)
 expect_snapshot_print(
-    modelsummary(mod, "markdown", align = "ld"),
-    "align-md_dcolumn")
\ No newline at end of file
+  modelsummary(mod, "markdown", align = "ld"),
+  "align-md_dcolumn"
+)
