@@ -11,12 +11,24 @@ x <- rnorm(100)
 y <- rnorm(100)
 z <- rnorm(100)
 mod <- lm(y ~ x + z)
-expect_error(modelsummary(mod, "data.frame", coef_map = c("x" = "X", "z" = "X")))
-expect_error(modelsummary(mod, "data.frame", coef_rename = c("x" = "X", "z" = "X")))
+expect_error(modelsummary(
+  mod,
+  "data.frame",
+  coef_map = c("x" = "X", "z" = "X")
+))
+expect_error(modelsummary(
+  mod,
+  "data.frame",
+  coef_rename = c("x" = "X", "z" = "X")
+))
 
 # across models works well
 mod <- list()
 mod[[1]] <- lm(y ~ x)
 mod[[2]] <- lm(y ~ z)
-tab <- modelsummary(mod, output = "data.frame", coef_map = c("x" = "X", "z" = "X"))
-expect_inherits(tab, "data.frame")
\ No newline at end of file
+tab <- modelsummary(
+  mod,
+  output = "data.frame",
+  coef_map = c("x" = "X", "z" = "X")
+)
+expect_inherits(tab, "data.frame")
