@@ -1,29 +1,37 @@
 models <- list(
   lm(hp ~ mpg + drat, mtcars),
-  lm(hp ~ mpg + drat, mtcars))
+  lm(hp ~ mpg + drat, mtcars)
+)
 
 # multiple estimates",{
-tab1 <- modelsummary(models,
+tab1 <- modelsummary(
+  models,
   output = "data.frame",
   gof_omit = ".*",
   stars = TRUE,
   statistic = NULL,
   estimate = c(
     "{estimate} ({std.error}){stars}",
-    "{estimate} [{conf.low}, {conf.high}]"))
-tab2 <- modelsummary(models,
+    "{estimate} [{conf.low}, {conf.high}]"
+  )
+)
+tab2 <- modelsummary(
+  models,
   output = "data.frame",
   gof_omit = ".*",
   stars = FALSE,
   statistic = NULL,
   estimate = c(
     "{estimate} ({std.error}){stars}",
-    "{estimate} [{conf.low}, {conf.high}]"))
+    "{estimate} [{conf.low}, {conf.high}]"
+  )
+)
 expect_true(all(tab1 == tab2))
 
 # error",{
 expect_error(
-  modelsummary(models,
+  modelsummary(
+    models,
     output = "data.frame",
     gof_omit = ".*",
     stars = TRUE,
@@ -31,4 +39,7 @@ expect_error(
     estimate = c(
       "estimate",
       "{estimate} ({std.error}){stars}",
-      "{estimate} [{conf.low}, {conf.high}]")))
\ No newline at end of file
+      "{estimate} [{conf.low}, {conf.high}]"
+    )
+  )
+)
