@@ -12,16 +12,31 @@ expect_false("gof" %in% tab2$part)
 # gof_map inputs are equivalent
 mod <- lm(mpg ~ hp, mtcars)
 gm <- tribble(
-    ~raw, ~clean, ~fmt,
-    "r.squared", "R-Squared", "%.7f")
+  ~raw,
+  ~clean,
+  ~fmt,
+  "r.squared",
+  "R-Squared",
+  "%.7f"
+)
 w <- modelsummary(mod, output = "data.frame", gof_map = gm)
 gm <- tribble(
-    ~raw, ~clean, ~fmt,
-    "r.squared", "R-Squared", function(x) sprintf("%.7f", x))
+  ~raw,
+  ~clean,
+  ~fmt,
+  "r.squared",
+  "R-Squared",
+  function(x) sprintf("%.7f", x)
+)
 x <- modelsummary(mod, output = "data.frame", gof_map = gm)
 gm <- tribble(
-    ~raw, ~clean, ~fmt,
-    "r.squared", "R-Squared", 7)
+  ~raw,
+  ~clean,
+  ~fmt,
+  "r.squared",
+  "R-Squared",
+  7
+)
 y <- modelsummary(mod, output = "data.frame", gof_map = gm)
 gm <- list(list(raw = "r.squared", clean = "R-Squared", fmt = 7))
 z <- modelsummary(mod, output = "data.frame", gof_map = gm)
@@ -31,15 +46,22 @@ expect_equivalent(w, z)
 
 # character vector
 mod <- lm(mpg ~ hp + drat, mtcars)
-tab <- modelsummary(mod,
-    gof_map = c("r.squared", "rmse", "nobs"),
-    output = "data.frame")
+tab <- modelsummary(
+  mod,
+  gof_map = c("r.squared", "rmse", "nobs"),
+  output = "data.frame"
+)
 expect_equivalent(tab$term[7:9], c("R2", "RMSE", "Num.Obs."))
-tab <- modelsummary(mod, gof_map = c("junk", "rmse", "nobs"), output = "data.frame")
+tab <- modelsummary(
+  mod,
+  gof_map = c("junk", "rmse", "nobs"),
+  output = "data.frame"
+)
 expect_inherits(tab, "data.frame")
 
 tab <- modelsummary(
-    mod,
-    output = "data.frame",
-    gof_map = "")
-expect_equivalent(nrow(tab), 6)
\ No newline at end of file
+  mod,
+  output = "data.frame",
+  gof_map = ""
+)
+expect_equivalent(nrow(tab), 6)
