@@ -5,8 +5,10 @@ using("tinysnapshot")
 # raw html output
 mod <- lm(hp ~ mpg, data = mtcars)
 expect_snapshot_print(
-    print_html(modelsummary(mod, gof_omit = ".*")),
-    "html-gof_omit.html") |> suppressWarnings()
+  print_html(modelsummary(mod, gof_omit = ".*")),
+  "html-gof_omit.html"
+) |>
+  suppressWarnings()
 
 # PR 538
 mod <- lm(mpg ~ hp + factor(cyl), data = mtcars)
