@@ -8,7 +8,10 @@ tab <- modelsummary(mod, "data.frame", statistic = "conf.int")
 expect_inherits(tab, "data.frame")
 tab <- modelsummary(mod, "data.frame", diagnostic = "ESS", statistic = "ess")
 expect_inherits(tab, "data.frame")
-expect_error(modelsummary(mod, "data.frame", statistic = "rope"), pattern = "available")
+expect_error(
+  modelsummary(mod, "data.frame", statistic = "rope"),
+  pattern = "available"
+)
 
 # modelplot
 mod <- marginaleffects:::modelarchive_model("brms_numeric2")
@@ -18,13 +21,14 @@ p <- modelplot(mod, draw = FALSE)
 expect_data_frame(p, nrows = 3)
 
 
-# mix brms and lm 
+# mix brms and lm
 modglm <- glm(am ~ mpg + hp, data = mtcars, family = binomial)
 models <- list(mod, modglm)
 
 tab <- modelsummary(
-    models,
-    coef_rename = \(x) gsub("b_", "", x),
-    coef_omit = "Intercept",
-    statistic = c("std.error", "conf.int"))
+  models,
+  coef_rename = \(x) gsub("b_", "", x),
+  coef_omit = "Intercept",
+  statistic = c("std.error", "conf.int")
+)
 expect_inherits(tab, "tinytable")
